summaryrefslogtreecommitdiffstats
path: root/src/usr/isteps/hbToHwsvVoltageMsg.H
diff options
context:
space:
mode:
Diffstat (limited to 'src/usr/isteps/hbToHwsvVoltageMsg.H')
-rw-r--r--src/usr/isteps/hbToHwsvVoltageMsg.H16
1 files changed, 12 insertions, 4 deletions
diff --git a/src/usr/isteps/hbToHwsvVoltageMsg.H b/src/usr/isteps/hbToHwsvVoltageMsg.H
index 5f66a2a9d..0f7e9704c 100644
--- a/src/usr/isteps/hbToHwsvVoltageMsg.H
+++ b/src/usr/isteps/hbToHwsvVoltageMsg.H
@@ -5,7 +5,7 @@
/* */
/* OpenPOWER HostBoot Project */
/* */
-/* Contributors Listed Below - COPYRIGHT 2012,2016 */
+/* Contributors Listed Below - COPYRIGHT 2012,2017 */
/* [+] International Business Machines Corp. */
/* */
/* */
@@ -91,6 +91,13 @@ public:
};
/**
+ * @brief Identifies hwsvPowrMemVoltDomainRequest_t as a DEFAULT voltage
+ * request if voltageMillivolts is set to this constant
+ *
+ */
+ const uint32_t VOLTAGE_SETTING_ALERT_DEFAULT = 0xFFFFFFFF;
+
+ /**
* @struct hwsvPowrMemVoltDomainRequest_t
*
* @brief Structure containing a memory voltage domain type, ID, and
@@ -234,9 +241,10 @@ private:
* @tparam MSS_DOMAIN_PROGRAM
* ID of the attribute to read to determine how we program this domain.
* Value of the attribute should be one of these:
* MSS_PROGRAM_TYPE::POWERON = no additional programming necessary,
* MSS_PROGRAM_TYPE::STATIC = use static value,
* MSS_PROGRAM_TYPE::DYNAMIC = use dynamic value
*
* @tparam VOLTAGE_ATTR_STATIC
* ID of the attribute which should be read to obtain the given memory
@@ -234,9 +241,10 @@ private:
* ID of the attribute to read to determine how we program this domain.
* Value of the attribute should be one of these:
- * MSS_PROGRAM_TYPE::POWERON = no additional programming necessary,
- * MSS_PROGRAM_TYPE::STATIC = use static value,
- * MSS_PROGRAM_TYPE::DYNAMIC = use dynamic value
+ * MSS_PROGRAM_TYPE::POWERON_TYPE = no add'l programming necessary,
+ * MSS_PROGRAM_TYPE::STATIC_TYPE = use static value,
+ * MSS_PROGRAM_TYPE::DYNAMIC_TYPE = use dynamic value,
+ * MSS_PROGRAM_TYPE::DEFAULT_TYPE = send special alert value
*
* @tparam VOLTAGE_ATTR_STATIC
OpenPOWER on IntegriCloud